#include <iostream>
#include <vector>
#include <algorithm>
#include <functional>

using namespace std;
using ll = long long;

#define SIEVE_UP_TO 1'000'000

vector<ll> primes{};
vector<bool> is_prime_table(SIEVE_UP_TO + 1, true);

void sieve_primes() {
    is_prime_table[0] = false;
    is_prime_table[1] = false;

    for (ll i = 2; i <= SIEVE_UP_TO; i++) {
        if (is_prime_table[i]) {
            primes.push_back(i);

            for (ll j = i * i; j <= SIEVE_UP_TO; j += i) {
                is_prime_table[j] = false;
            }
        }
    }
}

bool is_prime(ll x) {
    if (x <= SIEVE_UP_TO) {
        return is_prime_table[x];
    }

    for (ll prime : primes) {
        if (prime * prime > x) {
            return true;
        }

        if (x % prime == 0) {
            return false;
        }
    }

    for (ll i = primes.back() + 2; i * i <= x; i += 2) {
        if (x % i == 0) {
            return false;
        }
    }

    return true;
}

void handle_test() {
    int n, k;
    cin >> n >> k;

    vector<int> arr(n);
    ll sum = 0;

    for (auto& it : arr) {
        cin >> it;
        sum += it;
    }

    if (k == 1) {
        cout << (is_prime(sum) ? 1 : 0) << "\n";
        cout << n << " ";

        for (int i = 0; i < n; i++) {
            cout << arr[i] << " ";
        }

        cout << "\n";
    } else if (n <= 4) {
        int best = -1;
        vector<vector<int>> bests{};

        for (int a = 0; a < k; a++) {
            for (int b = 0; b < k; b++) {
                for (int c = 0; c < k; c++) {
                    for (int d = 0; d < k; d++) {
                        vector<int> abcd = { a, b, c, d };
                        vector<vector<int>> sequences(k);

                        for (int i = 0; i < n; i++) {
                            sequences[abcd[i]].push_back(arr[i]);
                        }

                        bool bad = false;

                        for (auto& seq : sequences) {
                            if (seq.size() == 0) {
                                bad = true;
                                break;
                            }
                        }

                        if (bad) {
                            continue;
                        }

                        int m = 0;

                        for (auto& seq : sequences) {
                            ll sseq = 0;

                            for (auto& it : seq) {
                                sseq += it;
                            }

                            if (is_prime(sseq)) {
                                m += 1;
                            }
                        }

                        if (m < best || best == -1) {
                            best = m;
                            bests = sequences;
                        }
                    }
                }
            }
        }

        cout << best << "\n";

                        for (const vector<int>& seq : bests) {
                            cout << seq.size() << " ";
                
                            for (int el : seq) {
                                cout << el << " ";
                            }
                
                            cout << "\n";
                        }
    } else if (n % 2 == 0 && arr[0] > 2) {
        vector<vector<int>> sequences{};

        for (int i = 0; i < arr.size(); i += 2) {
            k -= 1;
            sequences.push_back({ i, i + 1 });

            if (k == 0) {
                i += 2;

                for (; i < arr.size(); i++) {
                    sequences.back().push_back(i);
                }
            }
        }

        for (int i = 0; i < k; i++) {
            sequences.push_back({ sequences[i].back() });
            sequences[i].pop_back();
        }

        cout << (k * 2) << "\n";

        for (const vector<int>& seq : sequences) {
            cout << seq.size() << " ";

            for (int el : seq) {
                cout << arr[el] << " ";
            }

            cout << "\n";
        }
    } else {
        cout << "not implemented";
    }
}

int main() {
#ifndef DEBUG
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
#endif

    sieve_primes();

    int tests;
    cin >> tests;

    while (tests--) {
        handle_test();
    }

    return 0;
}
